*************************************************************************
* Setup
*************************************************************************
clear

/* Root filepath desired; default set to Mac users' downloads folder; please
change accordingly*/
global root ~/Downloads

/* Name of dataset exported from Qualtrics; change "dataset_name" below as appropriate */
global measurement_raw dataset_name

cd $root

*************************************************************************
* Importing Data
*************************************************************************

/* Import; do-file assumes data exported from Qualtrics using choice text and with
viewing order data, as a TSV file; if a CSV file has been exported by the user
instead, please change the tsv extension below to csv */

* Import eliminates the second and third rows of Qualtrics data export, which contains
* metadata and descriptions for each question
import delimited using "$root/$measurement_raw.tsv", clear varnames(1) encoding ("utf-16") rowrange(4)

*Renaming Variables from Qualtrics Export

* NOTE: it is possible that when importing qsf file or copying questions from imported
* qsf file to a new survey, the question identifiers below may change. The user
* should change the question identifiers below that may have changed

rename (q3_pagesubmit q7_pagesubmit ///
q11_pagesubmit q13_1 q13_2 q13_3 q13_4 q13_5 ///
q15_pagesubmit q17_1 q17_2 q17_3 q17_4 q17_5 ///
q19_pagesubmit q21_1 ///
q23_pagesubmit q25_1 q25_2 q25_3 q25_4 q25_5 ///
q27_pagesubmit q29_1 q29_2 q29_3 q29_4 q29_5 ///
q31_pagesubmit q33_1 q33_2 q33_3 q33_4 q33_5 ///
q35_pagesubmit q37_1 ///
q39_pagesubmit q41_1 q41_2 q41_3 q41_4 q41_5 ///
q38_pagesubmit ///
q51_pagesubmit q53_1 q53_2 q53_3 q53_4 q53_5 ///
q55_pagesubmit q57_1 q57_2 q57_3 q57_4 q57_5 ///
q59_pagesubmit q61_1 ///
q63_pagesubmit q65_1 q65_2 q65_3 q65_4 q65_5 ///
q67_pagesubmit q69_1 q69_2 q69_3 q69_4 q69_5 ///
q71_pagesubmit q73_1 q73_2 q73_3 q73_4 q73_5 ///
q75_pagesubmit q77_1 ///
q79_pagesubmit q81_1 q81_2 q81_3 q81_4 q81_5) ///
(socialgroups_pres_timer allocs_instr_timer ///
dom_univ_altru_left_timer1 dom_univ_altru_left_stranger1 dom_univ_altru_left_stranger2 dom_univ_altru_left_stranger3 dom_univ_altru_left_stranger4 dom_univ_altru_left_stranger5 ///
dom_univ_altru_left_timer2 dom_univ_altru_left_stranger6 dom_univ_altru_left_stranger7 dom_univ_altru_left_stranger8 dom_univ_altru_left_stranger9 dom_univ_altru_left_stranger10 ///
for_univ_altru_left_timer for_univ_altru_left_world ///
glo_univ_altru_left_timer glo_univ_altru_left_stranger1 glo_univ_altru_left_stranger2 glo_univ_altru_left_stranger3 glo_univ_altru_left_stranger4 glo_univ_altru_left_stranger5 ///
dom_univ_altru_right_timer1 dom_univ_altru_right_ingroup1 dom_univ_altru_right_ingroup2 dom_univ_altru_right_ingroup3 dom_univ_altru_right_ingroup4 dom_univ_altru_right_ingroup5 ///
dom_univ_altru_right_timer2 dom_univ_altru_right_ingroup6 dom_univ_altru_right_ingroup7 dom_univ_altru_right_ingroup8 dom_univ_altru_right_ingroup9 dom_univ_altru_right_ingroup10 ///
for_univ_altru_right_timer for_univ_altru_right_domestic ///
glo_univ_altru_right_timer glo_univ_altru_right_ingroup1 glo_univ_altru_right_ingroup2 glo_univ_altru_right_ingroup3 glo_univ_altru_right_ingroup4 glo_univ_altru_right_ingroup5 ///
trust_instr_timer ///
dom_univ_trust_left_timer1 dom_univ_trust_left_stranger1 dom_univ_trust_left_stranger2 dom_univ_trust_left_stranger3 dom_univ_trust_left_stranger4 dom_univ_trust_left_stranger5 ///
dom_univ_trust_left_timer2 dom_univ_trust_left_stranger6 dom_univ_trust_left_stranger7 dom_univ_trust_left_stranger8 dom_univ_trust_left_stranger9 dom_univ_trust_left_stranger10 ///
for_univ_trust_left_timer for_univ_trust_left_world ///
glo_univ_trust_left_timer glo_univ_trust_left_stranger1 glo_univ_trust_left_stranger2 glo_univ_trust_left_stranger3 glo_univ_trust_left_stranger4 glo_univ_trust_left_stranger5 ///
dom_univ_trust_right_timer1 dom_univ_trust_right_ingroup1 dom_univ_trust_right_ingroup2 dom_univ_trust_right_ingroup3 dom_univ_trust_right_ingroup4 dom_univ_trust_right_ingroup5 ///
dom_univ_trust_right_timer2 dom_univ_trust_right_ingroup6 dom_univ_trust_right_ingroup7 dom_univ_trust_right_ingroup8 dom_univ_trust_right_ingroup9 dom_univ_trust_right_ingroup10 ///
for_univ_trust_right_timer for_univ_trust_right_domestic ///
glo_univ_trust_right_timer glo_univ_trust_right_ingroup1 glo_univ_trust_right_ingroup2 glo_univ_trust_right_ingroup3 glo_univ_trust_right_ingroup4 glo_univ_trust_right_ingroup5)

* Drop other Qualtrics variables (click counts on screens, etc.)
drop q* fl*

* Importing with UTF-16 encoding imports all variables as string (though handles
* foreign language charactersm etc.), so we destring all numeric variables
destring, replace

*************************************************************************
* Processing Data
*************************************************************************

* Set total amount of money and trust points being split by respondents
global total_amount_money 100
global total_amount_points 100

********************** PROCESSING MONEY ALLOCATION DATA **********************

/*Since output from Qualtrics specifies the value of the slider, it represents
the amount of money allocated to the individual on the RIGHT of the slider;
as such, find allocation to the individual on the left (the in-groups) by
subtracting from 100, when respondent saw these on the left*/

local stranger_allocs dom_univ_altru_left_stranger1 dom_univ_altru_left_stranger2 ///
dom_univ_altru_left_stranger3 dom_univ_altru_left_stranger4 dom_univ_altru_left_stranger5 ///
dom_univ_altru_left_stranger6 dom_univ_altru_left_stranger7 dom_univ_altru_left_stranger8 ///
dom_univ_altru_left_stranger9 dom_univ_altru_left_stranger10 for_univ_altru_left_world ///
glo_univ_altru_left_stranger1 glo_univ_altru_left_stranger2 glo_univ_altru_left_stranger3 ///
glo_univ_altru_left_stranger4 glo_univ_altru_left_stranger5

foreach group of local stranger_allocs {
	replace `group' = $total_amount_money - `group'
}

rename (dom_univ_altru_left_stranger1 dom_univ_altru_left_stranger2 ///
dom_univ_altru_left_stranger3 dom_univ_altru_left_stranger4 dom_univ_altru_left_stranger5 ///
dom_univ_altru_left_stranger6 dom_univ_altru_left_stranger7 dom_univ_altru_left_stranger8 ///
dom_univ_altru_left_stranger9 dom_univ_altru_left_stranger10 for_univ_altru_left_world ///
glo_univ_altru_left_stranger1 glo_univ_altru_left_stranger2 glo_univ_altru_left_stranger3 ///
glo_univ_altru_left_stranger4 glo_univ_altru_left_stranger5) ///
(dom_univ_altru_left_ingroup1 dom_univ_altru_left_ingroup2 ///
dom_univ_altru_left_ingroup3 dom_univ_altru_left_ingroup4 dom_univ_altru_left_ingroup5 ///
dom_univ_altru_left_ingroup6 dom_univ_altru_left_ingroup7 dom_univ_altru_left_ingroup8 ///
dom_univ_altru_left_ingroup9 dom_univ_altru_left_ingroup10 for_univ_altru_left_domestic ///
glo_univ_altru_left_ingroup1 glo_univ_altru_left_ingroup2 glo_univ_altru_left_ingroup3 ///
glo_univ_altru_left_ingroup4 glo_univ_altru_left_ingroup5)

/*Generate variables depending on which presentation respondent saw*/

forvalues i = 1(1)10 {
	gen dom_univ_altru_ingroup`i'=.
}

forvalues i = 1(1)5 {
	gen glo_univ_altru_ingroup`i'=.
}

gen for_univ_altru_domestic=.

* Timers
gen dom_univ_altru_timer1=.
gen dom_univ_altru_timer2=.
gen for_univ_altru_timer=.
gen glo_univ_altru_timer=.

/*Filling In*/
local variants left right
foreach variant of local variants {
	forvalues i = 1(1)10 {
		replace dom_univ_altru_ingroup`i'=dom_univ_altru_`variant'_ingroup`i'/$total_amount_money if domestic_univ_altruism_on_`variant'==1
	}
	
	forvalues i = 1(1)5 {
		replace glo_univ_altru_ingroup`i'=glo_univ_altru_`variant'_ingroup`i'/$total_amount_money if global_univ_altruism_on_`variant'==1
	}	
	
replace for_univ_altru_domestic=for_univ_altru_`variant'_domestic/$total_amount_money if foreign_univ_altruism_on_`variant'==1

replace dom_univ_altru_timer1=dom_univ_altru_`variant'_timer1 if domestic_univ_altruism_on_`variant'==1
replace dom_univ_altru_timer2=dom_univ_altru_`variant'_timer2 if domestic_univ_altruism_on_`variant'==1
replace for_univ_altru_timer=for_univ_altru_`variant'_timer if foreign_univ_altruism_on_`variant'==1
replace glo_univ_altru_timer=glo_univ_altru_`variant'_timer if global_univ_altruism_on_`variant'==1

}

********************** PROCESSING TRUST DATA **********************

/*Since output from Qualtrics specifies the value of the slider, it represents
the relative trust in the individual on the RIGHT of the slider;
as such, find trust in the individual on the left (the in-groups)
by multiplying by -1, when respondent saw these on the left*/

local stranger_trust dom_univ_trust_left_stranger1 dom_univ_trust_left_stranger2 ///
dom_univ_trust_left_stranger3 dom_univ_trust_left_stranger4 dom_univ_trust_left_stranger5 ///
dom_univ_trust_left_stranger6 dom_univ_trust_left_stranger7 dom_univ_trust_left_stranger8 ///
dom_univ_trust_left_stranger9 dom_univ_trust_left_stranger10 for_univ_trust_left_world ///
glo_univ_trust_left_stranger1 glo_univ_trust_left_stranger2 glo_univ_trust_left_stranger3 ///
glo_univ_trust_left_stranger4 glo_univ_trust_left_stranger5

foreach group of local stranger_trust {
	replace `group'= $total_amount_points - `group'
}

rename (dom_univ_trust_left_stranger1 dom_univ_trust_left_stranger2 ///
dom_univ_trust_left_stranger3 dom_univ_trust_left_stranger4 dom_univ_trust_left_stranger5 ///
dom_univ_trust_left_stranger6 dom_univ_trust_left_stranger7 dom_univ_trust_left_stranger8 ///
dom_univ_trust_left_stranger9 dom_univ_trust_left_stranger10 for_univ_trust_left_world ///
glo_univ_trust_left_stranger1 glo_univ_trust_left_stranger2 glo_univ_trust_left_stranger3 ///
glo_univ_trust_left_stranger4 glo_univ_trust_left_stranger5) ///
(dom_univ_trust_left_ingroup1 dom_univ_trust_left_ingroup2 ///
dom_univ_trust_left_ingroup3 dom_univ_trust_left_ingroup4 dom_univ_trust_left_ingroup5 ///
dom_univ_trust_left_ingroup6 dom_univ_trust_left_ingroup7 dom_univ_trust_left_ingroup8 ///
dom_univ_trust_left_ingroup9 dom_univ_trust_left_ingroup10 for_univ_trust_left_domestic ///
glo_univ_trust_left_ingroup1 glo_univ_trust_left_ingroup2 glo_univ_trust_left_ingroup3 ///
glo_univ_trust_left_ingroup4 glo_univ_trust_left_ingroup5)

/*Generate variables depending on which presentation respondent saw*/

forvalues i = 1(1)10 {
	gen dom_univ_trust_ingroup`i'=.
}

forvalues i = 1(1)5 {
	gen glo_univ_trust_ingroup`i'=.
}

gen for_univ_trust_domestic=.

* Timers
gen dom_univ_trust_timer1=.
gen dom_univ_trust_timer2=.
gen for_univ_trust_timer=.
gen glo_univ_trust_timer=.

/*Filling In*/
local variants left right
foreach variant of local variants {
	forvalues i = 1(1)10 {
		replace dom_univ_trust_ingroup`i'=dom_univ_trust_`variant'_ingroup`i'/$total_amount_points if domestic_univ_trust_on_`variant'==1
	}
	
	forvalues i = 1(1)5 {
		replace glo_univ_trust_ingroup`i'=glo_univ_trust_`variant'_ingroup`i'/$total_amount_points if global_univ_trust_on_`variant'==1
	}	
	
replace for_univ_trust_domestic=for_univ_trust_`variant'_domestic/$total_amount_points if foreign_univ_trust_on_`variant'==1

replace dom_univ_trust_timer1=dom_univ_trust_`variant'_timer1 if domestic_univ_trustism_on_`variant'==1
replace dom_univ_trust_timer2=dom_univ_trust_`variant'_timer2 if domestic_univ_trustism_on_`variant'==1
replace for_univ_trust_timer=for_univ_trust_`variant'_timer if foreign_univ_trustism_on_`variant'==1
replace glo_univ_trust_timer=glo_univ_trust_`variant'_timer if global_univ_trustism_on_`variant'==1

}

drop *_left_* *_right_*

******************************************************************
* Generate variables displaying allocation given to each social group by each respondent
******************************************************************

local socialgroups extendedfamily orgmember neighbor friend_of_family ///
colleague samehobbies samereligion sameage samepolitics samerace

local foreigngroups forgn_samelanguage forgn_samereligion forgn_samerace ///
forgn_samevalues forgn_sameoccupation

foreach socialgroup of local socialgroups {
	gen `socialgroup'_alloc=.
	gen `socialgroup'_trust=.
}

foreach socialgroup of local foreigngroups {
	gen `socialgroup'_alloc=.
	gen `socialgroup'_trust=.
}

forvalues i = 1(1)10 {
	*Allocations
	replace extendedfamily_alloc=dom_univ_altru_ingroup`i' if strpos(group`i',"A member of your extended family")>0
	replace orgmember_alloc=dom_univ_altru_ingroup`i' if strpos(group`i',"A member of one of your past or current organizations")>0
	replace neighbor_alloc=dom_univ_altru_ingroup`i' if strpos(group`i',"Someone who lives in your local neighborhood")>0
	replace friend_of_family_alloc=dom_univ_altru_ingroup`i' if strpos(group`i',"A friend of a family member")>0
	replace colleague_alloc=dom_univ_altru_ingroup`i' if strpos(group`i',"A former or current colleague")>0
	replace samehobbies_alloc=dom_univ_altru_ingroup`i' if strpos(group`i',"interests or hobbies")>0
	replace samereligion_alloc=dom_univ_altru_ingroup`i' if strpos(group`i',"Someone who shares your religious beliefs")>0
	replace sameage_alloc=dom_univ_altru_ingroup`i' if strpos(group`i',"age/ generation")>0
	replace samepolitics_alloc=dom_univ_altru_ingroup`i' if strpos(group`i',"your political views")>0
	replace samerace_alloc=dom_univ_altru_ingroup`i' if strpos(group`i',"your same race/ ethnicity")>0

	*Trust
	replace extendedfamily_trust=dom_univ_trust_ingroup`i' if strpos(group`i',"A member of your extended family")>0
	replace orgmember_trust=dom_univ_trust_ingroup`i' if strpos(group`i',"A member of one of your past or current organizations")>0
	replace neighbor_trust=dom_univ_trust_ingroup`i' if strpos(group`i',"Someone who lives in your local neighborhood")>0
	replace friend_of_family_trust=dom_univ_trust_ingroup`i' if strpos(group`i',"A friend of a family member")>0
	replace colleague_trust=dom_univ_trust_ingroup`i' if strpos(group`i',"A former or current colleague")>0
	replace samehobbies_trust=dom_univ_trust_ingroup`i' if strpos(group`i',"interests or hobbies")>0
	replace samereligion_trust=dom_univ_trust_ingroup`i' if strpos(group`i',"Someone who shares your religious beliefs")>0
	replace sameage_trust=dom_univ_trust_ingroup`i' if strpos(group`i',"age/ generation")>0
	replace samepolitics_trust=dom_univ_trust_ingroup`i' if strpos(group`i',"your political views")>0
	replace samerace_trust=dom_univ_trust_ingroup`i' if strpos(group`i',"your same race/ ethnicity")>0		
}

forvalues i = 1(1)5 {
	*Allocations
	replace forgn_samelanguage_alloc=glo_univ_altru_ingroup`i' if strpos(foreign_group`i',"same language")>0
	replace forgn_samereligion_alloc=glo_univ_altru_ingroup`i' if strpos(foreign_group`i',"religious beliefs")>0
	replace forgn_samerace_alloc=glo_univ_altru_ingroup`i' if strpos(foreign_group`i',"race/ ethnicity")>0
	replace forgn_samevalues_alloc=glo_univ_altru_ingroup`i' if strpos(foreign_group`i',"values")>0
	replace forgn_sameoccupation_alloc=glo_univ_altru_ingroup`i' if strpos(foreign_group`i',"occupation")>0

	*Trust
	replace forgn_samelanguage_trust=glo_univ_trust_ingroup`i' if strpos(foreign_group`i',"same language")>0
	replace forgn_samereligion_trust=glo_univ_trust_ingroup`i' if strpos(foreign_group`i',"religious beliefs")>0
	replace forgn_samerace_trust=glo_univ_trust_ingroup`i' if strpos(foreign_group`i',"race/ ethnicity")>0
	replace forgn_samevalues_trust=glo_univ_trust_ingroup`i' if strpos(foreign_group`i',"values")>0
	replace forgn_sameoccupation_trust=glo_univ_trust_ingroup`i' if strpos(foreign_group`i',"occupation")>0		
}

******************************************************************************
* CONSTRUCTING UNIVERSALISM MEASURES
******************************************************************************

* Construction universalism in altruism
egen universalism_altruism_domestic=rowmean(extendedfamily_alloc orgmember_alloc neighbor_alloc friend_of_family_alloc colleague_alloc samehobbies_alloc samereligion_alloc sameage_alloc samepolitics_alloc samerace_alloc)
replace universalism_altruism_domestic=(1-universalism_altruism_domestic)*100

egen universalism_altruism_global=rowmean(forgn_*_alloc)
replace universalism_altruism_global=(1-universalism_altruism_global)*100

gen universalism_altruism_foreign=(1-for_univ_altru_domestic)*100

gen universalism_altruism_mean=(universalism_altruism_domestic + universalism_altruism_foreign + universalism_altruism_global)/3

* Construction universalism in trust
egen universalism_trust_domestic=rowmean(extendedfamily_trust orgmember_trust neighbor_trust friend_of_family_trust colleague_trust samehobbies_trust samereligion_trust sameage_trust samepolitics_trust samerace_trust)
replace universalism_trust_domestic=(1-universalism_trust_domestic)*100

egen universalism_trust_global=rowmean(forgn_*_trust)
replace universalism_trust_global=(1-universalism_trust_global)*100

gen universalism_trust_foreign=(1-for_univ_trust_domestic)*100

gen universalism_trust_mean=(universalism_trust_domestic + universalism_trust_foreign + universalism_trust_global)/3

* Summary statistic
egen universalism_composite=rowmean(universalism_altruism_mean universalism_trust_mean)

* Standardizing dependent variables into z-scores
foreach measure in universalism_altruism_domestic universalism_altruism_global ///
universalism_altruism_foreign universalism_altruism_mean universalism_trust_domestic ///
universalism_trust_global universalism_trust_foreign universalism_trust_mean universalism_composite {

	egen s_`measure'=std(`measure')

}

* Label variables
do "$root/Measurement_Tools_Package/Do-Files/label_vars_full"
